@@ -1,7 +1,7 @@
 filter.country<-function(data,country)
 {
   if(!is.data.frame(data) || !is.character(country) || !grepl("^[a-zA-Z]+$",gsub(" ", "", country)))
-     stop("invalid input parameter(s) specification")
+     stop("invalid input parameter(s) specification: check data/country")
  
   data(vmdbsite,envir=environment())
   vmdbsite<-get("vmdbsite",envir=environment())
